DB_SOURCE = "db_source"
SNOWFLAKE = "snowflake"
REDSHIFT = "redshift"
POSTGRESQL = "postgresql"


HOST = "host"
USERNAME = "user"
PASSWORD = "password"
ROLE = "role"
WAREHOUSE = "warehouse"
DATABASE = "database"

PSYCOPG2_KEY = "psycopg2"
REDSHIFT_DRIVER_KEY = "redshift+redshift_connector"

SSH_HOST = 'ssh_host'
SSH_USERNAME = 'ssh_username'
SSH_PEM_FILE_CONTENT = 'ssh_pem_file_content'

MISSING_MSG = 'is missing from Required credentials for SSH tunnel connection'
LOCALHOST = "localhost"
#logging color scheme
GREEN = "\033[92m"
RED = '\033[91m'
YELLOW = "\033[93m"
ENDC = '\033[0m'